{
    CONFIG      => {'order' => 'asc','tag' => '.'},
#    Twitter     => {'test' => 1},
    Identica    => {'username' => 'yourlogin','password' => 'yourpassword'},
}
